package com.taais.biz.service.impl;

import java.util.Arrays;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import com.taais.common.core.utils.MapstructUtils;
import com.taais.common.core.utils.StringUtils;
import com.taais.common.orm.core.page.PageQuery;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.orm.core.service.impl.BaseServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.taais.biz.mapper.AlgorithmTaskTrackMapper;
import com.taais.biz.domain.AlgorithmTaskTrack;
import com.taais.biz.domain.bo.AlgorithmTaskTrackBo;
import com.taais.biz.domain.vo.AlgorithmTaskTrackVo;
import com.taais.biz.service.IAlgorithmTaskTrackService;
import static com.taais.biz.domain.table.AlgorithmTaskTrackTableDef.ALGORITHM_TASK_TRACK;

/**
 * 可辨识性分析总任务Service业务层处理
 *
 * @author wangkang
 * 2025-01-06
 */
@Service
public class AlgorithmTaskTrackServiceImpl extends BaseServiceImpl<AlgorithmTaskTrackMapper, AlgorithmTaskTrack> implements IAlgorithmTaskTrackService {
    @Resource
    private AlgorithmTaskTrackMapper algorithmTaskTrackMapper;

    @Override
    public QueryWrapper query() {
        return super.query().from(ALGORITHM_TASK_TRACK);
    }

    private QueryWrapper buildQueryWrapper(AlgorithmTaskTrackBo algorithmTaskTrackBo) {
        QueryWrapper queryWrapper = super.buildBaseQueryWrapper();
        queryWrapper.and(ALGORITHM_TASK_TRACK.NAME.like
        (algorithmTaskTrackBo.getName()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.STATUS.eq
        (algorithmTaskTrackBo.getStatus()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.START_TIME.eq
        (algorithmTaskTrackBo.getStartTime()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.END_TIME.eq
        (algorithmTaskTrackBo.getEndTime()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.COST_SECOND.eq
        (algorithmTaskTrackBo.getCostSecond()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.LOG.eq
        (algorithmTaskTrackBo.getLog()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.REMARKS.eq
        (algorithmTaskTrackBo.getRemarks()));
        queryWrapper.and(ALGORITHM_TASK_TRACK.SYSTEM.eq
        (algorithmTaskTrackBo.getSystem()));

        return queryWrapper;
    }

    /**
     * 查询可辨识性分析总任务
     *
     * @param id 可辨识性分析总任务主键
     * @return 可辨识性分析总任务
     */
    @Override
    public AlgorithmTaskTrackVo selectById(Long id) {
            return this.getOneAs(query().where(ALGORITHM_TASK_TRACK.ID.eq(id)), AlgorithmTaskTrackVo.class);

    }

    /**
     * 查询可辨识性分析总任务列表
     *
     * @param algorithmTaskTrackBo 可辨识性分析总任务Bo
     * @return 可辨识性分析总任务集合
     */
    @Override
    public List<AlgorithmTaskTrackVo> selectList(AlgorithmTaskTrackBo algorithmTaskTrackBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(algorithmTaskTrackBo);
            return this.listAs(queryWrapper, AlgorithmTaskTrackVo.class);
    }

    /**
     * 分页查询可辨识性分析总任务列表
     *
     * @param algorithmTaskTrackBo 可辨识性分析总任务Bo
     * @return 分页可辨识性分析总任务集合
     */
    @Override
    public PageResult<AlgorithmTaskTrackVo> selectPage(AlgorithmTaskTrackBo algorithmTaskTrackBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(algorithmTaskTrackBo);
            Page<AlgorithmTaskTrackVo> page = this.pageAs(PageQuery.build(), queryWrapper, AlgorithmTaskTrackVo.class);
        return PageResult.build(page);
    }

    /**
     * 新增可辨识性分析总任务
     *
     * @param algorithmTaskTrackBo 可辨识性分析总任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insert(AlgorithmTaskTrackBo algorithmTaskTrackBo) {
    AlgorithmTaskTrack algorithmTaskTrack =MapstructUtils.convert(algorithmTaskTrackBo, AlgorithmTaskTrack. class);

        return this.save(algorithmTaskTrack);//使用全局配置的雪花算法主键生成器生成ID值
    }

    /**
     * 修改可辨识性分析总任务
     *
     * @param algorithmTaskTrackBo 可辨识性分析总任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    @Override
    public boolean update(AlgorithmTaskTrackBo algorithmTaskTrackBo) {
        AlgorithmTaskTrack algorithmTaskTrack =MapstructUtils.convert(algorithmTaskTrackBo, AlgorithmTaskTrack. class);
        if (ObjectUtil.isNotNull(algorithmTaskTrack) && ObjectUtil.isNotNull(algorithmTaskTrack.getId())){
            boolean updated = this.updateById(algorithmTaskTrack);
                return updated;
        }
        return false;
    }

    /**
     * 批量删除可辨识性分析总任务
     *
     * @param ids 需要删除的可辨识性分析总任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    @Transactional
    @Override
    public boolean deleteByIds(Long[] ids) {
        return this.removeByIds(Arrays.asList(ids));
    }

}
